@@ -1,5 +1,15 @@
 '''
-# replace this
+# lazy-constructs
+
+[![License](https://img.shields.io/badge/License-Apache%202.0-yellowgreen.svg)](https://opensource.org/licenses/Apache-2.0)
+[![codecov](https://codecov.io/gh/lazinessdevs/lazy-constructs/branch/main/graph/badge.svg?token=U1R3MKJWJO)](https://codecov.io/gh/lazinessdevs/lazy-constructs)
+
+[![NPM version](https://img.shields.io/npm/v/lazy-constructs?label=pypi%20package&color=brightgreen)](https://badge.fury.io/js/lazy-constructs)
+[![PyPI version](https://img.shields.io/pypi/v/lazy-constructs?label=pypi%20package&color=brightgreen)](https://badge.fury.io/py/lazy-constructs)
+[![NuGet version](https://img.shields.io/nuget/v/LazyConstructs?label=nuget%20package&color=brightgreen)](https://badge.fury.io/nu/LazyConstructs)
+[![Maven Central](https://img.shields.io/maven-central/v/com.lazinessdevs/lazyconstructs.svg?label=maven%20central&color=brightgreen)](https://search.maven.org/search?q=g:%22com.lazinessdevs%22%20AND%20a:%22lazy-constructs%22)
+
+[![release](https://github.com/lazinessdevs/lazy-constructs/actions/workflows/release.yml/badge.svg)](https://github.com/lazinessdevs/lazy-constructs/actions/workflows/release.yml)
 '''
 import abc
 import builtins
